library CompDate;
{ -------------------------------------------------------------------
                             CompDate
  -------------------------------------------------------------------
  Usage : A "fake" Delphi 1.0 Expert. It's not giving Delphi any
          extra ways of creating forms or other projects.
          It gives a unit which have a constant containing the
          date of compilation (or rather the date when the Delphi
          enviroment last were started) which can be used as a TDateTime
          date.
  Date  : 16 October 1996
  By    : Martin Djerns
  Legal : This libary (and source code) is copyright  1996 by
          Martin Djerns, but may be copied and distributed if You do
          not get any income by it.
          The package may not be modified or in other form altered
          without contacting the author first.
  INI   : Create a ini file in the same directory as this DLL file,
          with the same name.
          Add a section "[CompDate]" and to items "UnitName=" and "Path="
          UnitName is a way of giving the unit another name.
          Path is a way of placeing it someware else that your 
          \Delphi\Lib dirictory.
  Files : CompDate.DPR - This module
          Ver.RES      - Version information resource
          Snip.TXT     - Data to the generated unit
          Snip.RC      - To import the Snip.TXT into a RES file
          Build.BAT    - A batch file which builds the DLL file
          File_ID.DIZ  - Short description
  e-ail : djernaes@einstein.ot.dk
 -------------------------------------------------------------MDD96-- }

Uses
  ExptIntf,
  ToolIntf,
  VirtIntf,
  SysUtils,
  WinTypes,
  WinProcs,
  IniFiles,
  Classes;

{$R Snip.res}
{$R Ver.res}

{-- Procedures used to create the new unit ---------------------------}

{ Take the Snip from the resource and copies it to a text file
  placed in the dirictory specified in the INI file which have the
  same name and location as this DLL file.
  If this INI file does not exists the first path specified by the
  Delphi.INI file will be used as location and CompDate will be used
  as the unit name/file name.                                         }
Procedure Snip;
Var
  SnipResource : THandle;
  SnipSource,
  Buffer       : PChar;
  CompDateFile : TFileStream;
  Ini          : TIniFile;
  Path,
  UnitName     : String;
  APos         : Byte;
  Day,
  Month,
  Year         : Word;
Begin
  { Open the CompDate.INI file }
  Ini := TIniFile.Create(ChangeFileExt(ParamStr(0),'.INI'));
  Try
    { Get unit name - dafault is CompDate }
    UnitName := Ini.ReadString('CompDate','UnitName','CompDate');
    { Get the SearchPath loacation }
    Path := Ini.ReadString('CompDate','Path','');
  finally
    { Release the CompDate.INI file }
    Ini.Free;
  end;

  { If no path were specified }
  If Path = '' Then
  Begin
    { Open the Delphi.INI file }
    Ini := TIniFile.Create('Delphi.INI');
    Try
      { Get the full list of search pathes }
      Path := Ini.ReadString('Library','SearchPath','');
    finally
      { Release the Delphi.INI file }
      Ini.Free;
    end;

    { Find the first time a semicolon is in the search path }
    APos := Pos(';',Path);
    If APos > 0 Then { If there were a semicolon...}
      { Get the text before the semicolon }
      Path := Copy(Path,1,APos-1); 

    { If still no path were specified }
    If Path = '' Then
      Exit { Do not do more... }

  end;

  { If the last char not is backslack add an backslach } 
  If Path[Length(Path)] <> '\' Then
    Path := Path + '\';

  { Get the date }
  DecodeDate(Date,Year,Month,Day);

  { Load the Snip from the resource }
  SnipResource := LoadResource(HInstance,
    FindResource(HInstance, 'SNIP', RT_RCDATA));
  { Lock a pointer on the resource }
  SnipSource := LockResource(SnipResource);
  { Get a 1K buffer }
  Buffer := StrAlloc(1024);
  { Clear the buffer }
  FillChar(Buffer^,1024,#0);
  { Create the output file }
  CompDateFile :=
    TFileStream.Create(Path+UnitName+'.PAS', fmCreate);
  Try
    { Format the Ship and copy it over in the buffer - se Snip.TXT 
      for format string }
    StrFmt(Buffer,SnipSource,
      [UnitName,
       UnitName,
       DateToStr(Date),
       ExtractFileName(ParamStr(0)),
       Trunc(Date)] );
    { Write the formattet Snip }
    CompDateFile.Write(Buffer^, StrLen(Buffer));
  Finally
    CompDateFile.Free;            { Free file }
    UnlockResource(SnipResource); { Release the pointer to the resource }   
    FreeResource(SnipResource);   { Free the resource }
    StrDispose(Buffer);           { Free the buffer }
  end;
end;

{-- Procedures which are needed for Delphi til se the "fake" expert ---}

{ Register the expert so Delphi will accept loading it when Delphi
  are being started                                                }
Function InitExpert(    ToolServices: TIToolServices;
                        RegisterProc: TExpertRegisterProc;
                    var Terminate: TExpertTerminateProc): Boolean;
                                                               Export;
Begin
  Snip;
  Result := True;  { Say the registration vere success full }
End;

{ The way of handling faults in this module }
Function FaultHandler(FaultID: Word; faultAddr: Pointer): TFaultResponse; export;
Begin
  DefaultExceptHandler(FaultId, faultAddr);  { Use default }
End;

{ Export functions so Delphi can find them }
Exports
  InitExpert Name ExpertEntryPoint Resident,
  FaultHandler Name FaultHandlerSignature Resident;

Begin
end.

